# P4 Data Ingestion
> This package is used for creating dataset to be ingested into the Zooniverse Panoptes web-system for Citizen Science.


## Install

`pip install p4-data-ingestion`

## How to use

Please look at the `CTX pipeline` documentation for an example use case.
